package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.mapper.PosFenleiMapper;
import com.ruoyi.system.domain.PosFenlei;
import com.ruoyi.system.service.IPosFenleiService;

/**
 * spfenleiService业务层处理
 * 
 * @author ruoyi
 * @date 2023-05-21
 */
@Service
public class PosFenleiServiceImpl extends ServiceImpl<BaseMapper<PosFenlei>,PosFenlei> implements IPosFenleiService
{
    @Autowired
    private PosFenleiMapper posFenleiMapper;

    /**
     * 查询spfenlei
     * 
     * @param id spfenlei主键
     * @return spfenlei
     */
    @Override
    public PosFenlei selectPosFenleiById(Long id)
    {
        return posFenleiMapper.selectPosFenleiById(id);
    }

    /**
     * 查询spfenlei列表
     * 
     * @param posFenlei spfenlei
     * @return spfenlei
     */
    @Override
    public List<PosFenlei> selectPosFenleiList(PosFenlei posFenlei)
    {
        return posFenleiMapper.selectPosFenleiList(posFenlei);
    }

    /**
     * 新增spfenlei
     * 
     * @param posFenlei spfenlei
     * @return 结果
     */
    @Override
    public int insertPosFenlei(PosFenlei posFenlei)
    {
        return posFenleiMapper.insertPosFenlei(posFenlei);
    }

    /**
     * 修改spfenlei
     * 
     * @param posFenlei spfenlei
     * @return 结果
     */
    @Override
    public int updatePosFenlei(PosFenlei posFenlei)
    {
        return posFenleiMapper.updatePosFenlei(posFenlei);
    }

    /**
     * 批量删除spfenlei
     * 
     * @param ids 需要删除的spfenlei主键
     * @return 结果
     */
    @Override
    public int deletePosFenleiByIds(Long[] ids)
    {
        return posFenleiMapper.deletePosFenleiByIds(ids);
    }

    /**
     * 删除spfenlei信息
     * 
     * @param id spfenlei主键
     * @return 结果
     */
    @Override
    public int deletePosFenleiById(Long id)
    {
        return posFenleiMapper.deletePosFenleiById(id);
    }
}
